@@ -1,14 +1,20 @@
 #' Separate the series column in a tidy ABS time series data frame
 #'
 #' Separate the 'series' column in a data frame (tibble)
-#' downloaded using \code{read_abs()} into multiple columns using the ";" separator.
+#' downloaded using \code{read_abs()} into multiple columns using the ";"
+#' separator.
 #'
 #' @param data A data frame (tibble) containing tidied data from the ABS time
 #' series table(s).
-#' @param column_names (optional) character vector. Supply a vector of column names, such as
-#' \code{c("group_name", "variable","gender")}. If not supplied, columns will be named "series_1" etc.
-#' @param remove_totals logical. FALSE by default. If set to TRUE, any series rows that contain the word "total" will be removed.
-#' @param remove_nas locical. FALSE by default. If set to TRUE, any rows containining an NA in at least one of the separated series columns will be removed.
+#' @param column_names (optional) character vector. Supply a vector of column
+#' names, such as \code{c("group_name", "variable","gender")}. If not
+#' supplied, columns will be named "series_1" etc.
+#' @param remove_totals logical. FALSE by default.
+#' If set to TRUE, any series rows that contain the word "total"
+#' will be removed.
+#' @param remove_nas locical. FALSE by default. If set to TRUE, any rows
+#' containining an NA in at least one of the separated series columns
+#' will be removed.
 #'
 #' @return A data frame (tibble) containing the tidied data from the ABS time
 #' series table(s).
@@ -19,8 +25,9 @@
 #'
 #' \donttest{motor_vehicles <- read_abs("9314.0") %>% separate_series()}
 #'
-#' @importFrom stringr str_extract str_replace_all str_squish str_count
-#' @importFrom dplyr filter mutate_at syms
+#' @importFrom stringr str_count
+#' @importFrom stringi stri_trim_both
+#' @importFrom dplyr filter mutate_at sym
 #' @importFrom tidyr separate
 #' @importFrom purrr map_dfr
 
@@ -37,16 +44,23 @@ separate_series <- function(data,
   data <- mutate(data,
                  original_series = series)
 
+  fast_str_squish <- function(string) {
+    stringi::stri_trim_both(gsub("\\s+", " ", string, perl = TRUE))
+  }
+
   # Minor data cleaning of series column
   data <- mutate(data,
-                 series = str_extract(series, ".+(?= ;)"), #Extract everything before trailing ;
-                 series = str_replace_all(series, pattern = ">", replacement = ""),
-                 series = str_squish(series))
+                 #Extract everything before trailing ;
+                 series = regmatches(series,
+                                     regexpr(".+(?= ;)", series, perl = TRUE)),
+                 series = gsub(pattern = ">", series,
+                               replacement = "", perl = TRUE),
+                 series = fast_str_squish(series))
 
   # Filter totals if specified
-  if(remove_totals){
+  if (remove_totals) {
     data <- filter(data,
-                   !grepl("total", series, ignore.case = T))
+                   !grepl("total", series, ignore.case = T, perl = TRUE))
   }
 
   # Determine number of ; separators in series column
@@ -56,7 +70,7 @@ separate_series <- function(data,
   n_columns <- n_seps + 1
 
   # Create new column names if not specified
-  if(is.null(column_names)){
+  if (is.null(column_names)) {
     column_names <- paste("series", 1:n_columns, sep = "_")
   }
 
@@ -66,31 +80,33 @@ separate_series <- function(data,
                              sep = ";",
                              remove = FALSE,
                              fill = "left") %>%
-    mutate_at(.vars = vars(column_names), str_squish)
+    mutate_at(.vars = vars(column_names), fast_str_squish)
 
 
   # check for columns with NAs
-  na_columns <- paste0(colnames(data_separated)[colSums(is.na(data_separated)) > 0],
-                       collapse = ", ")
+  na_columns <- colnames(data_separated)[colSums(is.na(data_separated)) > 0]
 
-  if(na_columns != "" & !remove_nas){warning(na_columns, " column(s) have NA values.", call. = TRUE)}
+  if (length(na_columns) > 0 & !remove_nas) {
+
+    warning(paste0(na_columns, collapse = ", "),
+            " column(s) have NA values.", call. = TRUE)
+
+  }
 
   # filter NAs in new series columns
 
-  if(remove_nas & na_columns != "") {
+  if (remove_nas & length(na_columns) > 0) {
 
-    na_col_syms <- dplyr::syms(na_columns)
-
-    remove_na_fn <- function(data, column) {
-
-      data %>%
-        filter(!is.na( {{ column }} ))
+    remove_na_fn <- function(df, column) {
+      col_sym <- dplyr::sym(column)
 
+      df %>%
+        filter(!is.na(!!col_sym))
     }
 
-    data_separated <- purrr::map_dfr(.x = na_col_syms,
+    data_separated <- purrr::map_dfr(.x = na_columns,
         .f = remove_na_fn,
-        data = data_separated)
+        df = data_separated)
 
     message("Rows with NAs in separated series column(s) have been removed.")
 
@@ -107,8 +123,3 @@ separate_series <- function(data,
   return(data_separated)
 
 }
-
-
-
-
-
